storage

package
v0.0.0-...-354a747 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Closer

type Closer interface {
	Close() error
}

Closer is the interface that wraps the basic Close method.

type Iterator

type Iterator interface {
}

Iterator, only the leveldb storage engine support for now

type Kvs

type Kvs interface {
	Get(key string) []byte

	// Same as `Set`, WriteOptions will be added later
	Put(key string, value []byte) (bool, error)
	Delete(key string) (bool, error)

	Closer
	Iterator

	// Merge
	Merge() (bool, error)
}

Kvs is the interface to the key-value storage system

func Open

func Open(opts *options.KvsOptions) (Kvs, error)

Open database

Directories

Path Synopsis

Jump to