Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Closer ¶
type Closer interface {
Close() error
}
Closer is the interface that wraps the basic Close method.
type Iterator ¶
type Iterator interface {
}
Iterator, only the leveldb storage engine support for now
Click to show internal directories.
Click to hide internal directories.